@@ -24,7 +24,7 @@
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
 
-from psycopg2.extensions import (
+from psycopg2Crate.extensions import (
     new_type, new_array_type, register_type, register_adapter, QuotedString)
 
 # The module is imported on register_ipaddress
