@@ -27,9 +27,9 @@
 
 import re
 
-from psycopg2._psycopg import ProgrammingError, InterfaceError
-from psycopg2.extensions import ISQLQuote, adapt, register_adapter
-from psycopg2.extensions import new_type, new_array_type, register_type
+from psycopg2Crate._psycopg import ProgrammingError, InterfaceError
+from psycopg2Crate.extensions import ISQLQuote, adapt, register_adapter
+from psycopg2Crate.extensions import new_type, new_array_type, register_type
 
 
 class Range:
@@ -348,8 +348,8 @@ class RangeCaster:
 
         Raise `ProgrammingError` if the type is not found.
         """
-        from psycopg2.extensions import STATUS_IN_TRANSACTION
-        from psycopg2.extras import _solve_conn_curs
+        from psycopg2Crate.extensions import STATUS_IN_TRANSACTION
+        from psycopg2Crate.extras import _solve_conn_curs
         conn, curs = _solve_conn_curs(conn_or_curs)
 
         if conn.info.server_version < 90200:
