@@ -34,5 +34,5 @@ def lookup(code):
 
     Raise `!KeyError` if the code is not found.
     """
-    from psycopg2._psycopg import sqlstate_errors   # avoid circular import
+    from psycopg2Crate._psycopg import sqlstate_errors   # avoid circular import
     return sqlstate_errors[code]
