@@ -33,14 +33,14 @@ from collections import namedtuple, OrderedDict
 
 import logging as _logging
 
-import psycopg2
-from psycopg2 import extensions as _ext
+import psycopg2Crate
+from psycopg2Crate import extensions as _ext
 from .extensions import cursor as _cursor
 from .extensions import connection as _connection
 from .extensions import adapt as _A, quote_ident
 from functools import lru_cache
 
-from psycopg2._psycopg import (                             # noqa
+from psycopg2Crate._psycopg import (                             # noqa
     REPLICATION_PHYSICAL, REPLICATION_LOGICAL,
     ReplicationConnection as _replicationConnection,
     ReplicationCursor as _replicationCursor,
@@ -48,18 +48,18 @@ from psycopg2._psycopg import (                             # noqa
 
 
 # expose the json adaptation stuff into the module
-from psycopg2._json import (                                # noqa
+from psycopg2Crate._json import (                                # noqa
     json, Json, register_json, register_default_json, register_default_jsonb)
 
 
 # Expose range-related objects
-from psycopg2._range import (                               # noqa
+from psycopg2Crate._range import (                               # noqa
     Range, NumericRange, DateRange, DateTimeRange, DateTimeTZRange,
     register_range, RangeAdapter, RangeCaster)
 
 
 # Expose ipaddress-related objects
-from psycopg2._ipaddress import register_ipaddress          # noqa
+from psycopg2Crate._ipaddress import register_ipaddress          # noqa
 
 
 class DictCursorBase(_cursor):
@@ -536,7 +536,7 @@ class ReplicationCursor(_replicationCursor):
 
         if slot_type == REPLICATION_LOGICAL:
             if output_plugin is None:
-                raise psycopg2.ProgrammingError(
+                raise psycopg2Crate.ProgrammingError(
                     "output plugin name is required to create "
                     "logical replication slot")
 
@@ -544,14 +544,14 @@ class ReplicationCursor(_replicationCursor):
 
         elif slot_type == REPLICATION_PHYSICAL:
             if output_plugin is not None:
-                raise psycopg2.ProgrammingError(
+                raise psycopg2Crate.ProgrammingError(
                     "cannot specify output plugin name when creating "
                     "physical replication slot")
 
             command += "PHYSICAL"
 
         else:
-            raise psycopg2.ProgrammingError(
+            raise psycopg2Crate.ProgrammingError(
                 f"unrecognized replication type: {repr(slot_type)}")
 
         self.execute(command)
@@ -576,7 +576,7 @@ class ReplicationCursor(_replicationCursor):
             if slot_name:
                 command += f"SLOT {quote_ident(slot_name, self)} "
             else:
-                raise psycopg2.ProgrammingError(
+                raise psycopg2Crate.ProgrammingError(
                     "slot name is required for logical replication")
 
             command += "LOGICAL "
@@ -587,7 +587,7 @@ class ReplicationCursor(_replicationCursor):
             # don't add "PHYSICAL", before 9.4 it was just START_REPLICATION XXX/XXX
 
         else:
-            raise psycopg2.ProgrammingError(
+            raise psycopg2Crate.ProgrammingError(
                 f"unrecognized replication type: {repr(slot_type)}")
 
         if type(start_lsn) is str:
@@ -600,14 +600,14 @@ class ReplicationCursor(_replicationCursor):
 
         if timeline != 0:
             if slot_type == REPLICATION_LOGICAL:
-                raise psycopg2.ProgrammingError(
+                raise psycopg2Crate.ProgrammingError(
                     "cannot specify timeline for logical replication")
 
             command += f" TIMELINE {timeline}"
 
         if options:
             if slot_type == REPLICATION_PHYSICAL:
-                raise psycopg2.ProgrammingError(
+                raise psycopg2Crate.ProgrammingError(
                     "cannot specify output plugin options for physical replication")
 
             command += " ("
@@ -755,7 +755,7 @@ def wait_select(conn):
     therefore is able to handle/receive SIGINT/KeyboardInterrupt.
     """
     import select
-    from psycopg2.extensions import POLL_OK, POLL_READ, POLL_WRITE
+    from psycopg2Crate.extensions import POLL_OK, POLL_READ, POLL_WRITE
 
     while True:
         try:
@@ -777,7 +777,7 @@ def wait_select(conn):
 def _solve_conn_curs(conn_or_curs):
     """Return the connection and a DBAPI cursor from a connection or cursor."""
     if conn_or_curs is None:
-        raise psycopg2.ProgrammingError("no connection or cursor provided")
+        raise psycopg2Crate.ProgrammingError("no connection or cursor provided")
 
     if hasattr(conn_or_curs, 'execute'):
         conn = conn_or_curs.connection
@@ -868,7 +868,7 @@ class HstoreAdapter:
         start = 0
         for m in self._re_hstore.finditer(s):
             if m is None or m.start() != start:
-                raise psycopg2.InterfaceError(
+                raise psycopg2Crate.InterfaceError(
                     f"error parsing hstore pair at char {start}")
             k = _bsdec.sub(r'\1', m.group(1))
             v = m.group(2)
@@ -879,7 +879,7 @@ class HstoreAdapter:
             start = m.end()
 
         if start < len(s):
-            raise psycopg2.InterfaceError(
+            raise psycopg2Crate.InterfaceError(
                 f"error parsing hstore: unparsed data after char {start}")
 
         return rv
@@ -960,7 +960,7 @@ def register_hstore(conn_or_curs, globally=False, unicode=False,
     if oid is None:
         oid = HstoreAdapter.get_oids(conn_or_curs)
         if oid is None or not oid[0]:
-            raise psycopg2.ProgrammingError(
+            raise psycopg2Crate.ProgrammingError(
                 "hstore type not found in the database. "
                 "please install it from your 'contrib/hstore.sql' file")
         else:
@@ -1017,7 +1017,7 @@ class CompositeCaster:
 
         tokens = self.tokenize(s)
         if len(tokens) != len(self.atttypes):
-            raise psycopg2.DataError(
+            raise psycopg2Crate.DataError(
                 "expecting %d components for the type %s, %d found instead" %
                 (len(self.atttypes), self.name, len(tokens)))
 
@@ -1051,7 +1051,7 @@ class CompositeCaster:
         rv = []
         for m in self._re_tokenize.finditer(s):
             if m is None:
-                raise psycopg2.InterfaceError(f"can't parse type: {s!r}")
+                raise psycopg2Crate.InterfaceError(f"can't parse type: {s!r}")
             if m.group(1) is not None:
                 rv.append(None)
             elif m.group(2) is not None:
@@ -1106,7 +1106,7 @@ ORDER BY attnum;
             pass
 
         if not recs:
-            raise psycopg2.ProgrammingError(
+            raise psycopg2Crate.ProgrammingError(
                 f"PostgreSQL type '{name}' not found")
 
         type_oid = recs[0][0]
@@ -1249,7 +1249,7 @@ def execute_values(cur, sql, argslist, template=None, page_size=100, fetch=False
         [(1, 20, 3), (4, 50, 6), (7, 8, 9)])
 
     '''
-    from psycopg2.sql import Composable
+    from psycopg2Crate.sql import Composable
     if isinstance(sql, Composable):
         sql = sql.as_string(cur)
 
